==> vue-cli-plugin-lib-1.0.3-beta.3.tgz: package/index.js <==
/*
 * @Author: 文贝
 * @Date: 2022-08-30 21:13:13
 * @LastEditors: 陶慧灵
 * @LastEditTime: 2022-11-17 17:34:42
 * @Descripttion:
 * @FilePath: \vue-cli-plugin-lib\index.js
 */
const defaults = {
  clean: true,
  target: "app",
  formats: "umd-min",
  "unsafe-inline": true,
};

module.exports = (api, options) => {
  api.registerCommand(
    "build:lib",
    {
      description: "build for production",
      usage: "vue-cli-service build:package [options] [entry|pattern]",
      options: {
        "--mode": `specify env mode (default: production)`,
        "--dest": `specify output directory (default: ${options.outputDir})`,
        "--modern": `build app targeting modern browsers with auto fallback`,
        "--no-unsafe-inline": `build app without introducing inline scripts`,
        // "--target": `app | lib | wc | wc-async (default: ${defaults.target})`,
        "--inline-vue":
          "include the Vue module in the final bundle of library or web component target",
        "--formats": `list of output formats for library builds (default: ${defaults.formats})`,
        "--name": `name for lib or web-component mode (default: "name" in package.json or entry filename)`,
        "--filename": `file name for output, only usable for 'lib' target (default: value of --name)`,
        "--no-clean": `do not remove the dist directory before building the project`,
        "--report": `generate report.html to help analyze bundle content`,
        "--report-json": "generate report.json to help analyze bundle content",
        "--skip-plugins": `comma-separated list of plugin names to skip for this run`,
        "--watch": `watch for changes`,
        "--stdin": `close when stdin ends`,
      },
    },
    async (args) => {
      args.target = "lib";
      // 默认输出umd-min
      if (!args.formats) args.formats = "umd-min";
      args.entry = args.entry || args._[0]
      if (args.target !== 'app') {
        args.entry = args.entry || 'src/index.js'
      }
      api.chainWebpack((config) => {
        let externals = {
          vue: "vue",
          vuex: "vuex",
          "vue-router": "vue-router",
          "@icreate/core": "@icreate/core",
          "@icreate/ics-chromely-js-sdk":"@icreate/ics-chromely-js-sdk",
          "@icreate/ics-chromely-plugin-core":"@icreate/ics-chromely-plugin-core",
          "@imedx/ics-imedx-chromely-plugin-intf-platform":"@imedx/ics-imedx-chromely-plugin-intf-platform",
          "@/utils/hb-request": "@/utils/hb-request",
          "@/utils/imedx-server": "@/utils/imedx-server",
          "@/utils/request": "@/utils/request",
          "./utils/event-bus": "./utils/event-bus",
          "@/utils/event-bus": "@/utils/event-bus",
          "js-cookie": "js-cookie",
          "@icreate/ics-ui": "@icreate/ics-ui",
          "@icreate/ics-icon":"@icreate/ics-icon",
          "@icreate/ics-utils":"@icreate/ics-utils", 
          "@icreate/ics-ui/lib/ics-ui.css": "@icreate/ics-ui/lib/ics-ui.css",
          "element-ui": "element-ui",
          "element-ui/lib/theme-chalk/index.css": "element-ui/lib/theme-chalk/index.css",
          "normalize.css/normalize.css": "normalize.css/normalize.css",
          "nprogress":"nprogress",
          "nprogress/nprogress.css":"nprogress/nprogress.css",
          "@imedx/ics-imedx-permission":"@imedx/ics-imedx-permission"
        }
        // 非Icon打包模式
        if(!args.icon) 
          externals["@icreate/ics-icon"] = "@icreate/ics-icon";
        config.set("externals", externals);
        
        config.module
          .rule("js")
          .use("babel")
          .loader("babel-loader")
          .tap((options) => {
            return options;
          });        
      });
      
      options.css.extract = true;
      await api.service.run("build", args);
    }
  );
};

module.exports.defaultModes = {
  "build:lib": "production",
};

==> vue-cli-plugin-lib-1.0.4-beta.3.tgz: package/index.js <==
/*
 * @Author: 文贝
 * @Date: 2022-08-30 21:13:13
 * @LastEditors: 陶慧灵
 * @LastEditTime: 2022-11-17 17:34:42
 * @Descripttion:
 * @FilePath: \vue-cli-plugin-lib\index.js
 */
const defaults = {
  clean: true,
  target: "app",
  formats: "umd-min",
  "unsafe-inline": true,
};

module.exports = (api, options) => {
  api.registerCommand(
    "build:lib",
    {
      description: "build for production",
      usage: "vue-cli-service build:package [options] [entry|pattern]",
      options: {
        "--mode": `specify env mode (default: production)`,
        "--dest": `specify output directory (default: ${options.outputDir})`,
        "--modern": `build app targeting modern browsers with auto fallback`,
        "--no-unsafe-inline": `build app without introducing inline scripts`,
        // "--target": `app | lib | wc | wc-async (default: ${defaults.target})`,
        "--inline-vue":
          "include the Vue module in the final bundle of library or web component target",
        "--formats": `list of output formats for library builds (default: ${defaults.formats})`,
        "--name": `name for lib or web-component mode (default: "name" in package.json or entry filename)`,
        "--filename": `file name for output, only usable for 'lib' target (default: value of --name)`,
        "--no-clean": `do not remove the dist directory before building the project`,
        "--report": `generate report.html to help analyze bundle content`,
        "--report-json": "generate report.json to help analyze bundle content",
        "--skip-plugins": `comma-separated list of plugin names to skip for this run`,
        "--watch": `watch for changes`,
        "--stdin": `close when stdin ends`,
      },
    },
    async (args) => {
      args.target = "lib";
      // 默认输出umd-min
      if (!args.formats) args.formats = "umd-min";
      args.entry = args.entry || args._[0]
      if (args.target !== 'app') {
        args.entry = args.entry || 'src/index.js'
      }
      api.chainWebpack((config) => {
        let externals = {
          vue: "vue",
          vuex: "vuex",
          "vue-router": "vue-router",
          "@icreate/core": "@icreate/core",
          "@icreate/ics-iform":"@icreate/ics-iform",
          "@icreate/ics-chromely-js-sdk":"@icreate/ics-chromely-js-sdk",
          "@icreate/ics-chromely-plugin-core":"@icreate/ics-chromely-plugin-core",
          "@imedx/ics-imedx-chromely-plugin-intf-platform":"@imedx/ics-imedx-chromely-plugin-intf-platform",
          "@/utils/hb-request": "@/utils/hb-request",
          "@/utils/imedx-server": "@/utils/imedx-server",
          "@/utils/request": "@/utils/request",
          "./utils/event-bus": "./utils/event-bus",
          "@/utils/event-bus": "@/utils/event-bus",
          "js-cookie": "js-cookie",
          "@icreate/ics-ui": "@icreate/ics-ui",
          "@icreate/ics-icon":"@icreate/ics-icon",
          "@icreate/ics-utils":"@icreate/ics-utils", 
          "@icreate/ics-ui/lib/ics-ui.css": "@icreate/ics-ui/lib/ics-ui.css",
          "element-ui": "element-ui",
          "element-ui/lib/theme-chalk/index.css": "element-ui/lib/theme-chalk/index.css",
          "normalize.css/normalize.css": "normalize.css/normalize.css",
          "nprogress":"nprogress",
          "nprogress/nprogress.css":"nprogress/nprogress.css",
          "@imedx/ics-imedx-permission":"@imedx/ics-imedx-permission",
          "@imedx/ics-imedx-chromely-plugin-index-examine":"@imedx/ics-imedx-chromely-plugin-index-examine",
          "@imedx/ics-chromely-plugin-imedx":"@imedx/ics-chromely-plugin-imedx"
        }
        // 非Icon打包模式
        if(!args.icon) 
          externals["@icreate/ics-icon"] = "@icreate/ics-icon";
        config.set("externals", externals);
        
        config.module
          .rule("js")
          .use("babel")
          .loader("babel-loader")
          .tap((options) => {
            return options;
          });            
          
          // 生产环境下去除console
          if (process.env.NODE_ENV === 'production') {
            config.optimization.minimizer('terser').tap(args => {
              const compress = args[0].terserOptions.compress;
              // 非 App 平台移除 console 代码(包含所有 console 方法，如 log,debug,info...)  
              compress.drop_console = true;
              // compress.pure_funcs = [  
              //     '__f__' // App 平台 vue 移除日志代码  
              //     // 'console.debug' // 可移除指定的 console 方法  
              // ];  
              return args;
            });
          }
      });
      
      options.css.extract = true;
      await api.service.run("build", args);
    }
  );
};

module.exports.defaultModes = {
  "build:lib": "production",
};
